@@ -1,3 +1,38 @@
+# ***** BEGIN LICENSE BLOCK *****
+# Version: MPL 1.1/GPL 2.0/LGPL 2.1
+#
+# The contents of this file are subject to the Mozilla Public License Version
+# 1.1 (the "License"); you may not use this file except in compliance with
+# the License. You may obtain a copy of the License at
+# http://www.mozilla.org/MPL/
+#
+# Software distributed under the License is distributed on an "AS IS" basis,
+# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+# for the specific language governing rights and limitations under the
+# License.
+#
+# The Original Code is "pypi2rpm"
+#
+# The Initial Developer of the Original Code is Mozilla Foundation.
+# Portions created by the Initial Developer are Copyright (C) 2010
+# the Initial Developer. All Rights Reserved.
+#
+# Contributor(s):
+#   Tarek Ziade (tarek@mozilla.com)
+#
+# Alternatively, the contents of this file may be used under the terms of
+# either the GNU General Public License Version 2 or later (the "GPL"), or
+# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+# in which case the provisions of the GPL or the LGPL are applicable instead
+# of those above. If you wish to allow use of your version of this file only
+# under the terms of either the GPL or the LGPL, and not to allow others to
+# use your version of this file under the terms of the MPL, indicate your
+# decision by deleting the provisions above and replace them with the notice
+# and other provisions required by the GPL or the LGPL. If you do not delete
+# the provisions above, a recipient may use your version of this file under
+# the terms of any one of the MPL, the GPL or the LGPL.
+#
+# ***** END LICENSE BLOCK *****
 import string
 import os
 import sys
@@ -65,6 +100,11 @@ class bdist_rpm2(bdist_rpm):
             '%define unmangled_version ' + version,
             '%define release ' + self.release.replace('-','_'),
             '',
+        
+            '\\\n'.join(['%define __os_install_post'
+                       , '%( rpm --eval %%__os_install_post)'
+                       , "( cd $RPM_BUILD_ROOT; find . -type f | sed -e 's/^.//') > INSTALLED_FILES"]) ,
+
             'Summary: ' + summary,
             ]
 
@@ -324,7 +364,12 @@ class bdist_rpm2(bdist_rpm):
 
         # Make a source distribution and copy to SOURCES directory with
         # optional icon.
-        saved_dist_files = self.distribution.dist_files[:]
+
+        try:
+            saved_dist_files = self.distribution.dist_files[:]
+        except AttributeError:
+            # no dist_files attibut in old distutils version (python 2.4 for instance)
+            saved_dist_files = []
 
         try:
             sdist = self.reinitialize_command('sdist')
@@ -338,7 +383,10 @@ class bdist_rpm2(bdist_rpm):
             sdist.formats = ['gztar']
 
         self.run_command('sdist')
-        self.distribution.dist_files = saved_dist_files
+        try:
+            self.distribution.dist_files = saved_dist_files
+        except AttributeError:
+            pass
 
         source = sdist.get_archive_files()[0]
         source_dir = rpm_dir['SOURCES']
@@ -400,6 +448,9 @@ class bdist_rpm2(bdist_rpm):
         self.spawn(rpm_cmd)
 
         if not self.dry_run:
+            if not os.path.isdir(self.dist_dir):
+                raise DistutilsFileError('%s is not a dir' % self.dist_dir)
+
             if not self.binary_only:
                 srpm = os.path.join(rpm_dir['SRPMS'], source_rpm)
                 assert(os.path.exists(srpm))
@@ -410,4 +461,3 @@ class bdist_rpm2(bdist_rpm):
                     rpm = os.path.join(rpm_dir['RPMS'], rpm)
                     if os.path.exists(rpm):
                         self.move_file(rpm, self.dist_dir)
-
