@@ -1,4 +1,4 @@
-#!/home/tarek/dev/hg.mozilla.org/account-portal/bin/python
+#!/Users/tarek/Dev/hg.mozilla.org/server-devtools/bin/python
 import os
 import sys
 import tempfile
@@ -11,6 +11,7 @@ from ConfigParser import ConfigParser
 import collections
 import re
 import urllib
+import urllib2
 
 import distutils2.version
 from distutils2.index.simple import Crawler, DEFAULT_SIMPLE_INDEX_URL
@@ -33,6 +34,21 @@ def get_release(project_name, version=None,
                 download_cache=None):
     if os.path.exists(project_name):
         return project_name
+
+    if (project_name.startswith('http://') or
+        project_name.startswith('https://')):
+        filename = project_name.split('/')[-1]
+
+        if download_cache is not None:
+            filename = os.path.join(download_cache, filename)
+
+        content = urllib2.urlopen(project_name).read()
+
+        with open(filename, 'w') as f:
+            f.write(content)
+
+        return os.path.abspath(filename)
+
     c = Crawler(index_url=index_url, prefer_final=True)
     project = c.get_releases(project_name)
     if version is None:
@@ -353,6 +369,8 @@ distutils2.version._PREDICATE = _PREDICATE
 
 
 def main(project, dist_dir, version, index_url, download_cache):
+    if os.path.isfile(project):
+        project = os.path.abspath(project)
     release = get_release(project, version, index_url, download_cache)
     if release is None:
         return 1
